Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

15x15 - Season 15 Reunion

Episode transcripts for the TV show, "Project Runway". Aired: December 1, 2004 – present.*
Watch/Buy Amazon


Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.

15x15 - Season 15 Reunion

Post by bunniefuu »

TIM:
Tonight on the Project Runway

season 15 reunion...

Mwah, mwah!

TIM: The designers and I
come together

to take a look back.

Many of you had quite
a lot to say.

Everything that I said,
I made sure

I said it to your face.

I thought we were all buddies.

There were... a lot of tears

this season.

Wait, are you crying right now?

No... d-damn it, man!

I wouldn't change anything
for the world.

-Was a dream come true.
-To see that

-was-was really remarkable.
-Very touched by it.

We'll get to the bottom

of some of the hot topics
from the season.

Did you really think
you were working well together?

-Yeah, I did, because...
-I didn't.

"This sucks.
It's so ugly."

Don't be smug and abrasive
if you can't handle it, like...

-One-One-One second.
-I need to go outside.

TIM:
Maybe touch on some things

that they don't want
to talk about.

Who would you shag,
marry or k*ll?

[designers groan]

I want to hear
about that [bleep].

-[laughing]: I know where
this is going. -[laughs]

No reunion has ever
gone here before.

-[laughs]
-[Tim laughs]

TIM: And they're determined
to settle some scores.

You guys were
actually really fake.

-I wasn't fake to anybody.
-Yes, you were, honey.

Mah-Jing would be

rude to me and disrespectful.

Girl, sip your champagne.

DEXTER:
Shady.

♪ ♪

TIM: From FIDM
in Downtown Los Angeles...

welcome to the Project Runway
season 15 reunion special.

We have a lot to talk about.

And, designers, welcome back.
I'm so thrilled

to see all of you.
I've missed you.

-Timmy.
-Missed you, too.

-Timmy.
-[all laughing]

TIM:
First, we'll talk to the final

seven designers.

The rest of the designers

I have to say, you all look

so rested than
when I last saw you.

-Yes.
-Ugh, so much sleep.

-TIM: Yeah?
-It's a whole new world.

-Yes, it is.
-LAURENCE: Makes you sleep.

The non-runway world.

-Yes, it is, yes, it is.
-[Tim laughs]

And, Erin...

congratulations on your win.

Thank you.

[designers cheer]

TIM:
Cheers.

-Cheers!
-Cheers.

-Cheers.
-Yay!

Oh, sorry clinks. Um...

[laughter]

-RIK: Cheers.
-Here you go.

Has it sunk in?

It's sinking in every day

-more and more. Yeah.
-Yeah?

And watching every episode
is making it

make sense, so, yeah,

-it's a whole new world.
-Well, I have to say, your road

to the win was not exactly
an easy one.

Definitely not.

Well, let's take a look
at your journey.

Oh, my God.

So, what kind of stuff
do you do?

I make clothes and art.

I love fun

and just energy in my work.

-[exaggerated]: No.
-And I-I rea...

[laughs]

One of my favorite pieces
I've seen

in many seasons.

Congratulations,

you are the winner

-of the first challenge.
-Thank you.

HEIDI:
This is a wow piece.

You love this fabric.

NINA:
It almost felt like we were

under the ocean,
looking at a jellyfish.

It was really extraordinary.

HEIDI: Is she going
to a c*ck party

or a costume party?

NINA:
I'm disappointed because I...

know that you could do
better work.

Mom.

I'm surprised that this

is your look, Erin.

ZAC:
You're a mastress

of mixed medium and material.

-Well done.
-Thank you.

HEIDI:
You really gave us

-a fashion show today.
-Brava.

I have seen some really

memorable pieces from you.

I mean, unforgettable pieces.

Erin, you are the winner

of Project Runway season 15!

Oh, my God, I can't even

believe this is real.

It is real.
She did it.

-[laughter]
-TIM: So, Erin, how did you

feel when the judges
were speaking

about your work rather harshly?

The thing that I feel
like I experienced

through Project Runway is just,

like, a little glimpse of life.

Life isn't always on the top.

-No.
-You do have these low moments.

Sometimes you're on the top and
sometimes you're on the bottom.

-So...
-That's very true. And now...

-It was all worth it.
-Was all... for a reason.

-Yeah.
-So, we have to talk

about your obsession
with yellow.

Let's take a look, everyone.

ERIN:
I just went crazy with yellow.

I have this

banana case for my phone.

And I just love

to just hold it,
and it's just...

-it's, like, comforting.
-TIM: Wow.

And I got the color
that I wanted.

You certainly did.

-Ooh.
-Okay.

I mean, obviously,
I have to get the yellow.

Could maybe do, like, two
and a half and it might work.

I'm going with the yellow.

-You're... Miss Yellow.
-[laughs]

-[laughter] -TIM:
So, where does it come from?

It comes from my banana case,
my-my cell phone case.

You know, bananas are
a great fruit, and...

The banana is the origin
of all this.

ERIN: The banana, yeah.
And yellow is just, like,

this energetic, happy color.
And also it's,

like, this color that a lot
of people don't really wear,

-It's true. -and so they see it,
it's kind of,

like, this... surprise. So...

TIM: And as you see yourself
moving forward

as a designer, do you see yellow

-remaining...?
-I-I don't know.

I like to keep it open.
I really do love all colors.

And I actually wasn't gonna do
yellow in my collection,

-and then I was like, who am I?
-[laughter]

-Well, congratulations
on your win. -Thank you.

-It's quite a thrilling thing.
-Thank you. Yeah.

TIM: Roberi, I have to ask you,
you were so close

-to the win,
-Yes.

yet it didn't happen.
How did that feel for you?

I'm really happy
with the result.

I really loved my collection.

NINA: Your clothes look
not only beautiful,

you also make it alive.

You had it always in you.

Bravo.

Being on the program

and almost winning,

for me, it's-it's just amazing.

It's an amazing opportunity
to be here with you guys.

TIM: And I'm gonna add,
you gave up a lot to be here.

You left your family,

you left your loved ones,

and that's a lot of sacrificing.

It is.

It's difficult.

It's difficult
to have my family,

uh, back in Venezuela,

but hopefully,
that will change...

someday.

And for my whole country,
it's... it have to change.

-And how do you feel about
where you are now? -I have a job

in fashion studio
in New York, and...

-yes, I'm-I'm working, so...
I'm doing -Excellent.

what I really,
really love to do,

-and I'm very happy.
-Wonderful.

TIM: So, Rik,
you won the AARP challenge,

-I did. Yes. -with your mother
as your client.

And the two of you won $50,000.

-Yes.
-What does that mean for you?

It's amazing.
I mean, I think we could,

um, go on
a family vacation now.

So I'm definitely
looking forward to that.

-You're not investing it in your
brand? -I'm planning on maybe

doing my own
separate collection,

-Okay.
-um, runway show, so I think

that will definitely go
into that as well.

-Wonderful. Now, Laurence...
-Yes, sir.

You are our quiet,

-thoughtful, tenacious and
determined designer. -Uh-huh.

-Okay.
-[laughter]

What has being on Project Runway
done for you?

My Web site
is going out of control,

-Oh, good. -and, um, I have a
lot of orders, and I'm talking

to some, um, people about
working on, um, luxury cars

-for later. Yeah.
-Luxury cars?

-Wow! That's so cool! -TIM:
Luxury cars? How interesting.

-She been working.
-That's dope.

They want me to do some couture,
uh, items for them, so...

That's really wonderful.
Well, we dug through

miles and miles of footage,

and found quite a few moments in
which you let your guard down.

And many of them involve

the language barrier.

Let's take a look.

When I think fashion,
it's all French

-in my head, so...
-Say it in French, then.

[speaking French]

Voilà.

Like, um... how do you call

those big bracelets?

How do you call those jackets

with the little tail
in the back?

Is that a tuxedo jacket?

How do you call that neck?

Like we say in France,

actually all the teams
right now are kif-kif.

-Ca va?
-NATHALIA: What does that mean?

-"How are you?"
-Oh. Teach me more.

-What do you want to know?
-"Where's the bathroom?"

Ou sont le toilet?

Ou sont
le toilet?

Le toilet.

Ou sont le toilet?

Toilet.
Toi.

Ou sont toilet?

Ou sont le toilet?

Ou sont
le toilet?

[both laugh]

Still don't know how to say it.

Atypique.

Do you guys use that word?
A... Atypique?

How do you call that...

Hmm.

How do you call that?

English is complicated, ah?

[laughter]

-I love her.
-ERIN: She's so cute.

TIM:
That was a lot of fun.

Well, there was something
that wasn't so fun.

And that was the team challenge

that put together Dexter,
Erin and Cornelius.

-CORNELIUS: Here it comes.
-Uh-oh. -Oh... -And...

it didn't work out very well.

Do you all remember that one?

-I forgot about it. -ERIN:
I think it worked out great.

[laughter]

-Let's take a look.
-Oh...

We should hard-core stick
to that theme of color.

-Oh, I definitely agree with
you. -I most definitely feel

like I am an outsider,

because they are best friends.

-You should do a jacket dress.
-I think that

makes, like, the most sense.

I almost want to do, like,
an oversized coat for mine.

CORNELIUS:
I just feel like it's too much.

DEXTER:
Currently, Erin and I

are leading the charge.

Cornelius isn't
totally into it.

You know, I mean, I have, like,

a low level of trust
for most people

anyway, so I'm still, like...

CORNELIUS: I'm looking
at the collection

and it's just screaming

very red-- you need to, like,
tone it down a little bit.

Honestly, I'm feeling,
like, really good

-about it.
-I am, too.

CORNELIUS:
My teammates are

slacking, they're laughing,

they're taking breaks.

I am so over this.

RIK: Cornelius is freaking out
while Erin

and Dexter are
just kind of, like...

[laughter]

HEIDI:
You guys were the weakest.

I believe it's
because the red is overwhelming.

Dexter, who out of your team do
you think should go home today?

I'm... I'm gonna have
to say Cornelius.

Hmm.

Erin...

Cornelius,
how do you feel about that?

I think it's, like,
a stab in the back.

Just because you guys
are friends, don't throw me

under the ... bus
in front of those people.

Take ownership of what you did.

-I'm taking ownership of it now!
-That's all I'm saying.

I just have to say it-- we have
two mean girls on that team

and they beat up on him.

Cornelius, I'm sorry.

You're out.

CORNELIUS:
It's a design competition,

not a popularity contest.

They have to go to bed
throwing someone

under the bus,
knowing damn well who

actually did the work.

TIM:
Cornelius,

you're not going anywhere.

♪ ♪

I am using

my Tim Gunn save.

[excited shouts]

TIM:
Come here.

[people clapping]

Ooh.

TIM:
Cornelius,

do you think you
should have been eliminated?

No.

-No.
-Because I did

pull a lot of load in that team.

But you just got
to make compromises,

and if no one wants
to listen to your voice...

you got to go--
you're gonna go down in flames.

TIM:
And, Erin and Dexter,

how did you feel
when I saved him?

We were forced in the position

to have to choose
to who goes home.

I don't think that
he should've gone home.

I don't think Dexter
should've gone home.

I don't think
I should've gone home.

And that's why I actually am

-happy you used your save.
-Well,

that's why I saved Cornelius.

Yeah, but I definitely have
issues with the way that

the whole episode was portrayed.

It was, like, hurtful 'cause
I thought we were having fun.

-And like...
-Wasn't edited accurately?

-I don't think so.
-I don't think so either.

ERIN: I think that we all
worked really hard

and I was hurt.
Also you called us mean girls.

And I don't think
that we were mean girls.

We were making jokes
and having fun.

CORNELIUS: Why didn't anybody
tell me I had this sticker

on my a*s that says $9.95?

[laughter]

-Damn it.
-ERIN: Yes!

CORNELIUS:
You guys are stupid for that.

And for only 99 cents,

you can have Cornelius.

-[chuckling]
-Right?

And, Cornelius, how do you feel
about the editing?

I thought it was
portrayed perfect.

[snickers]

Yes, Cori!
Yeah!

CORNELIUS: It made perfect
sense, both of them

did say to me, they go,
"Oh, we're gonna go

take a break, okay?"

I'm like, "All right."
And I'm just gonna

keep on sewing and keep on going

'cause I didn't take
a break that day.

At one point we were
in the sewing room,

and I felt his-his heat
coming from him.

Remember, I said, "Listen, calm
down. Let's get it together,

do what you got to do,
and make it work."

ALEX:
I will say, with that episode,

I think it humanized Cornelius
so much more.

Yeah, that's true, that's true.

I wasn't gonna sit there
and have

half-assed stuff

go in front of people and have
them, like, judge it.

I don't think our collection
was half-assed.

-And you didn't think so either.
-That's why I'm bothered

because I feel like
you lied to us.

-What do you mean by that?
-I just think

that you were saying
way nastier stuff

behind the camera
and I had no idea

-you felt like that.
-Well, Erin,

maybe if you actually
listened to me,

-you would know, but you didn't.
-[laughs]

DEXTER: Well, maybe if you had
more to say about

coming up with another plan
versus just saying no.

You waited till after
we got the fabric

and said "I hate all the red."

-You gave no options...
-You can't say

I didn't give you options
because I tried.

And you guys
didn't want to take it.

And if you take who was actually

working their butt off...

-Oh.
-DEXTER: I helped you out, too.

You're saying I didn't
help you sew things, too?

-All three of us did it.
-I... can't.

ERIN:
That's why I feel lied to

'cause I was surprised at how
well we were working together.

Did you really think you were
working well together?

-Yeah, I did, because...
-I didn't.

[laughter]

From my point of view,

the editing is kind to everyone.

And not even remotely
inaccurate.

And I love the two of you,

I sincerely do,

you marginalized Cornelius.

-You were marginalized.
-MAH-JING: I can see why

you guys would say,
"Hey, we were good together."

But it looked like, as if,
okay, he's the outsider.

And then he was just put up.

Even though that's not
what y'all meant,

it just didn't look right.

TIM:
Well, on that topic,

in the same challenge,

you felt marginalized

-from your team members.
-They tribal.

-[laughter]
-They tri...

-They did, I felt like,
you know what? -What did he say?

'Cause they really
pissed me off.

I know one of them
had so much to say.

Well, we're going
to talk about this

when we come back.

-I'm so ready.
-[Tim laughs]

TIM: Coming up on the Project
Runway season 15 reunion...

NATHALIA: You would be rude
to me and disrespectful.

-Why would you
come at me like that? -Bam.

NATHALIA:
But you guys don't know me.

-So much drama.
-MAH-JING: Oh, man.

♪ ♪

Welcome back.

And welcome Nathalia and Jenni.

-It's nice to see you again.
-Thank you, it's good

-to be back.
-Thank you.

TIM:
Let's take a look

at how Team Neutral did

in the challenge

with the pop-up shop.

So the team will begin with...

-Jenni.
-[gasps] Yay!

-And Nathalia.
-Oh, hey.

TIM:
And...

-Mah-Jing.
-Yay.

-[laughs] -MAH-JING:
Them two are friends

in the competition.

Once again,

I am the outsider

in a team challenge.

NATHALIA: This is what I had
in mind to make.

It's like a... long jacket.

MAH-JING: I think we could
do something dope.

Between Jenni's street style,

my sexiness,

and Nathalia's...

JENNI: I can't envision
what he's making.

I'm drawing it out right now.

NATHALIA:
I'm just trying to envision

how we're gonna tie in
the blue denim.

They're not allowing me to add

any opinion on anything.
They're not taking

what I have to say seriously.

JENNI: I am kind of worried

about the dynamic
of Nathalia and Mah-Jing.

-NATHALIA: Jenni.
-JENNI: Yes, girl?

-Come over here real quick.
-Okay, one second.

MAH-JING:
I'm frustrated at this point.

I find myself working by myself,

and then Jenni and Nathalia
are constantly

having small little
meetings together.

You know how we got
that beautiful extra wool?

-Yeah. -How about I line
my jacket with it,

and then it will be reversible.

JENNI:
Yeah.

NATHALIA: We are doing what
we want to do,

so, like, we're just
telling Mah-Jing, like,

you know, do whatever you want.

So we're all just kind
of working separately.

You want to ask Mah-Jing, too,
so he doesn't think

we're having a secret meeting?

-Oh.
-[laughing]

They're making it seem like
I don't know what I'm doing.

If I didn't know
what I was doing,

I damn sure wouldn't
have been here.

Now come on, y'all.

I just think it's disrespectful.

-[groaning]: Oh, man.
-TIM: Well, there's a lot

-to talk about.
-MAH-JING: Yes, it is.

And, Mah-Jing, how are you
feeling about all of this now?

I still feel the sa--
pretty much the same way.

I felt like the lack of respect
for me, as a designer,

and what I bring
to the competition.

And I didn't understand,
exactly,

where in the hell

did you get me being,
like, this enemy with you?

We all got our own
different aesthetic,

so why would you come
at me like that?

It's evident that the two of you
had difficulties together.

The problem that you had with me

was from the beginning
in the competition.

-When? When? I never even
said nothing... -Well...

I helped you the first--
The first challenge,

I gave you my-my word of advice.

-When did I give you a hard
time? -But one-one-one second.

I need some clarification here.

-Fiery. -NATHALIA [on TV]:
I don't know what I

ever did to him for him
to dislike me so much.

-It's like really astonishing.
-TIM: But you're saying it...

It started at the beginning
of the season, you're saying.

Yeah, Mah-Jing would be rude
to me and disrespectful

-behind the camera.
-MAH-JING: Yo, please,

don't sit up here and act like
I was rude to you; if anything

that Mah-Jing Wong did behind
the scenes, or in front

of the camera, was because
it was a call for a reaction.

NATHALIA: I don't know.
I just feel like you kind of

seek out to have,
like a confrontation with me.

Girl, you-- Okay.

I see, Nathalia's young,

so some of the things she do,
she not even aware of.

Yeah, but you guys
don't know me.

It's called actions.

Mah-Jing, just a second. Jenni?

Being the outsider of the
problem that you two have,

I felt like I was more of
a mediator in the situation,

-and we had a great end result.
-Yeah.

I never had a problem with you.

-I don't have a problem
with you. -Yeah.

And we managed to make
a beautiful situation

-out of something that wasn't.
-So question:

Did I or did I not work well
as a team?

-We designed the jacket
together. -Yeah. -Yeah.

And by the end of the challenge,

we all did come together.

So I don't have no bad blood
for Nathalia.

I just wanted to stick up
for myself, because honestly,

we can agree to disagree
on a topic.

-That's true.
-TIM: All right.

-So much drama. -TIM:
We're going to take a break.

[laughing]: And when we come
back, we'll have the rest

of the designers join us.

TIM: Coming up on the Project
Runway season 15 reunion...

It was a very emotional day.

Now I'm about to cry.

I need to go outside.
[laughs]

[designers imitating
Jenni's laugh]

-And what about me?
-[Jenni laughing]

Welcome back
to the Project Runway

season 15 reunion special.

We now have 15
of our 16 designers.

-Sarah couldn't make it.
-DESIGNERS: Aw, Sarah.

But she did send
a special message

-to all of you.
-DESIGNERS: Oh.

-Hi, everyone.
-Sarah.

SARAH: I'm so sorry
I can't be there.

Although, actually, I'm not,
because I'm, uh,

about to board a plane to go
to Maui, to go on my honeymoon.

-[laughter]
-Don't worry,

I bought my bathing suit;
I didn't make it.

[laughter]

I love you and miss you all,

and I really hope I can
see you soon... Bye.

[smooches]

-Bye, Sarah.
-Love you.

So, Brik,

everyone seems
to absolutely love you.

-You have a way about you that's
very special. -[Brik laughs]

-And we want to take a look
at that way. -BRIK: Uh-oh.

-My little southern belle.
-[laughter]

So there's this theory

that from an
evolutionary standpoint,

that humans are drawn

towards shiny objects because of
their constant search for water.

Glitter's everywhere.

I think it'll look really cool

if the glue sticks, but they
definitely do look like

something a unicorn would wear
if it had, like, um...

I guess... I guess a unicorn
could wear them.

I'd have to make
some alterations.

How is the glitter adhered?

-A various cornucopia of glues.
-[laughs]

-RIK: We're gonna only talk
in Spanish. -BRIK: Nosotros.

-Sombrero.
-ERIN: I love Brik.

His personality
is [bleep] awesome.

And he's such
a weird character.

I've never met anyone like him.

-How was your fitting?
-It was good. Uh...

She looks kind of like
the dress form,

but she has, like, legs and arms
and a head.

[laughter]

-Oh, snap.
-[laughter]

-How did you all feel
about having... -I love Brik.

-having Brik in the workroom? -I
love Brik. -TASHA: I love him.

And he from Louisiana,
so it make it even better.

Thank you for loving me.

TIM:
Well, Tasha,

you have a very lovable way
about you, too.

-Oh. -And there is something
very special about you

-that kept us laughing.
-Thank you.

-Let's... take a look.
-JENNI: Yeah.

-Hello, hello.
-Where are you guys from?

TASHA:
A lot of people have told me

that you don't seem like
the type to be a designer,

and I never knew that
a designer had a look.

-Tasha.
-Hey, Boss Man.

[laughs]

TASHA: Heidi is snapping.

-Heidi works.
-[laughter]

-TASHA: Messing with this.
-TIM: Oh, dear.

I'm really horrified right now.

-Bam.
-[laughter]

Each of you will receive $5,000
to build your business.

-Thanks to Mary Kay.
-TASHA: I grew up with nothing.

So this is a blessing for me.

You have a star
and a light in you,

and you're gonna go beyond...

TASHA: I feel like I did
a hell of a good job.

This just was part
of the journey.

-Now I'm about to cry.
-ERIN: Happy tears.

-MAH-JING: Oh, Tash.
-TIM: How did all of you

feel about having Tasha
in the workroom?

It was so good. She's secretly
over there, like, the quietest.

And then she's like, oh, yeah,
I gave you guys all nicknames.

-And we're like, oh, my God.
-JENNI: Yeah, that was adorable.

What were your nicknames?

Mah-Jing was "Denim Dream."

Kimber was "Timber."

Dexter was "D-Town."

Erin was "Cute-E."

Brik was "Bayou Boy."

Alex was "Mister."

[laughing]

And what about me?
I know.

-"Boss Man."
-TIM: Yes.

-Proudly.
-[laughter]

Alex, there was a team challenge

in which you felt responsible
for the outcome of your team.

It was a very emotional day

for everyone
and especially you.

So we're gonna have
a look at that.

-Fantastic.
-[laughter]

Team Unity,
you're the losing team.

Who should go home?

Unfortunately, one of you guys
has to go home today.

-Roberi...
-I will put myself.

Roberi, are you saying
that you should go home?

Yes.

-Cornelius...
-CORNELIUS [crying]: I'm sorry.

I just can't do this to them.

So I'll go home for mine.

Nathalia, what about you?

NATHALIA:
If you guys hate my jacket

the most, then I'd say
you could send me home.

Alex, what about you?

I failed on the pitch.

I failed my team.
They put their trust into me.

So if there's anybody that
deserves to go home, it's me.

None of these people, at all.

HEIDI:
Does that mean you gave up?

ALEX:
I'm not giving up.

I would love to stay here

and show you what I have,

but at the same time,
with everybody,

I have to take accountability.

[sighs] Okay.

[applause, chatter]

Aw... I love you, Alex.

I need to go outside.

[laughter]

Alex, what was it like,
reliving that?

ALEX:
It's rough.

When we first found out
that we were on the bottom,

I knew exactly what
I was going to do,

because I did the pitch

and I believed so much
in my team--

and I think it goes to show
in the season

how talented my team was.

And I'm very content.

I wouldn't change anything
for the world.

Well, it was
a very noble thing to do

and a very inspiring thing to do

and it was unprecedented.

How did the rest of you feel

about that whole experience?

The reason why
we were all crying--

well, why I was crying
onstage was because

Alex is literally
sacrificing himself for us

and it was such an amazing

-team player thing to do.
-Mm-hmm.

It was also a very difficult
challenge from the beginning,

because we thought we had,
like, a very strong concept

and then a very strong
collection and...

it end up being, like,
not at all.

To see that sportsmanship was...
was really remarkable.

-Jenni...
-JENNI: Yes.

What's up, Tim?

TIM: While your fashion
is very memorable,

there's something else about you

that's memorable as well.

Yeah, and no one can
recreate it, so...

-[laughing]
-TIM: Well, let's take a look

and a listen.

My laugh is different.

[laughing]

You got a laugh.

You got a laugh!

-[Jenni continues laughing];
-I can't...

Oh, my God...

Jenni's laugh makes my world.

[laughing]

So it's kind of like this:

[imitates Jenni's laugh]

A little bit.

[laughter]

[creaking inhale]

[imitates hiccuping laugh]

It kind of sounds like

I would, I would imagine,
like, if you

just punched a donkey real hard

and they started "hawing."

[Jenni laughs]

-It just goes...
-[Jenni laughing]

...and goes.

[Jenni laughing]

-And you're done.
-[Jenni laughing]

-[Jenni laughing]
-[laughter]

Oh, my gosh.

-Stop it, Jenni.
-All day.

Oh.

[laughs]
-JENNI: That is too much.

-Haw, haw.
-TIM: All right.

Who among you has
the best Jenni laugh?

-I think Kimber did it
pretty good. -Yeah, Kimber.

-Kimber?
-TASHA: Kimber did a good job.

-[Kimber guffawing]
-Right. -Hey! -Ah!

-I told you.
-TIM: That's good.

Yeah, Linda did it
pretty good, too.

-[Linda guffawing]
-[laughter]

We are going
to take a quick break,

-and we'll be right back.
-[laughter]

TIM: Coming up on the Project
Runway season 15 reunion...

I'm just very touched by it.

Wait. Are you crying right now?

Aw. Damn it, man!

You can never say that I was
ever fake about something.

-Yeah, I can. I just did.
-Everything that I said I made

-sure I said it to your face.
-No, you didn't.

♪ ♪

Welcome back.

Every season, we hear words

that we've never heard before.

-[laughter]
-I know where this is going.

TIM:
And one of you in particular

introduced us
to the shnew-shnew.

-[laughter]
-[Dexter muffling laughter]

-Let's take a look.
-[laughter]

This is like shnew-shnew
and... [whistles] ...city.

I'm imagining her with, like,
just holding a staff

on a mountain and being,
like,

"Oh, we sacrifice shnew-shnew
to giant gorilla."

There's nothing wrong
with a little exposed

poom-poom on the runway.

Oh, a unicorn and a mermaid

did the... [whistles]
...and then

I came floating out
of the ocean like magic.

You'd have to be really careful
and appliqué over her [whistles]

-because otherwise, it's gonna
be a... [whistles] show. -Ooh.

[whistles]

-[laughter]
-JENNI: You're so funny, Dexter.

Dexter, you are truly unique.
We've never had anyone quite

-like you on the show.
-Oh, thank you, Tim.

TIM:
Well, you all know

that Project Runway is
very difficult,

it's very demanding,
and it's very emotional.

There were a lot of tears
this season.

-Let's take a look.
-[Erin sniffles, cries]

-I feel like they're very, um,
intense designers. -Mm.

Very passionate.
They cry a lot.

[crying]: I'm just so grateful
that I had such

an amazing, like, team
to work with.

-[crying]
-Yes, babe.

For me to win it is...

[crying]:
something I would never forget.

[sniffles]

[crying]: I didn't think
that this competition

was gonna be this difficult.

[crying]

ROBERI [crying]:
I miss my family.

I haven't seen them in so...
in so long.

-Daddy!
-[crying]

I'm really blessed to be here.

Oh, Mah-Jing.

[Mah-Jing cries]

Oh, Mah-Jing is crying.

Mah-Jing cries and cries
and cries.

He's been crying all day!

-[Mah-Jing crying]
-Oh, Jing, Jing.

I knew they was gonna
say something about it,

but I had to stand by it.

Mah-Jing, Mah-Jing, Mah-Jing.

Stop crying, Mah-Jing, man.

And I don't see his eyes
anymore.

-It's the ancient Chinese side.
-Exactly. -[laughter]

I want to see him do that
girly-- that girly cry he does.

-[Laurence and Dexter imitate
Mah-Jing's laugh] -[laughter]

[crying]

Mah-Jing is a sensitive soul,

and, hey,
that's not a bad thing.

And I'm grateful to be a dad.

I'm a damn good dad.

You got another chance, brother.

I think your son really
did a great job.

-Oh, yeah.
-TIM: Mah-Jing!

-Mah-Jing, are you crying again?
-TASHA: Again! -[laughter]

-Every time someone goes home.
-Are you crying right now?

-Ah, damn it, man! That's a
look. -TIM: But you must have

been exhausted
by the time you left the show.

MAH-JING:
You know what?

I wasn't that in touch
with my emotions

until my daughter came
into this world.

And the reason why I push myself
is because of her.

And a lot of those emotions--

I was fighting for my life
when I came here.

With 16 cents in my pocket.

Each challenge that I got
through in this competition,

literally, I started to blossom.

-I feel a lot stronger,
so I'm good. -TIM: Did the rest

of you expect this experience
to be so emotional?

-LAURENCE: No!
-CORNELIUS: I did. I was like,

-"Oh, my gosh." -I didn't
expect it to be so much crying.

I decided that when I came on
the show, that I didn't

have no kids, no family,
no friends, and that was it.

-What do you mean? -Well, I
mean, to stay strong and focus.

When I saw Mah-Jing
when he talks to his daughter

and he went downhill,
I was like, "Hell, no."

-[laughter] -Marley, I am not
calling you. -TIM: So is that

-why you were so stoic during
the season? -Oh, no. Yeah. Yeah.

-Because you just didn't want
to let these emotions in? -No.

-Yeah. -TIM: Well, during
your home visit, you became

-very emotional. -Mm-hmm. Yeah,
because there was no more

challenges, and we were going
to Fashion Week, so

-I was like this... [whooshes]
-I was very touched by it.

-Thank you. Thank you.
-Very touched by it.

I saw a side of you
that was just...

even more beautiful
than this side.

-Mwah. Mwah. Mwah. Mwah. Mwah.
-[laughter]

TIM:
Cornelius?

[laughter]

You had a nickname.

Do you know what it was?

Lady Cornelius
from the land of who?

-ALL: Shade!
-[laughter]

All right, well,
let's take a look at

-Lady Cornelius
from the land of Shade. -Ooh!

-Yeah.
-Alter ego, man, alter ego.

Uh-oh, royalty is in the room.

-Lady Cornelius from the land
of Shade. -[laughter]

Who does she look like?

You're gonna throw some shade?

I think you might need
to turn this light up

'cause I'm sensing some shade
coming from across the room.

Oh, my God, here we go.

But those pants?

Cornelius is, like, kind of here
with the idea that,

like, he is gonna be
the bitchy one.

He's just giving me constant
resting b*tch face.

LAURENCE: I don't like
the side of him--

bashing people,
for a reason or not...

I think I'm actually starting

to see people
brushing him off a little bit.

He'll claw you real quick.

DEXTER: I don't know how
he has any friends because

everyone
in the competition knows

he's talking about them.

He just be running that mouth.

CORNELIUS: I think in Erin
the judges are seeing,

mm... I don't know
what they're seeing.

Cornelius is like a little
mosquito, like, zz, zz, zz, zz.

It doesn't affect me.

-Ooh.
-Ooh.

So, Cornelius,
what's that about?

-Nothing. You know what?
Honestly... -Oh, nothing?

I thought it was pretty funny
throughout the season.

-You know what I mean?
-NATHALIA: I thought so, too.

It was all in a joking manner.

It wasn't really like,
"Oh, I'm really just

gonna come at you just to come
at you." You know what I mean?

It's all love.
If I don't like your outfit--

-and Nathalia knows this...
-I was just gonna say, Tim...

...that means
that I really like it.

He was the same exact way
in school.

And usually
when he was negative,

it's because
you were doing something good

that he was kind of jealous of,

so he'll be like,
"Oh, yeah, that's not good."

-Ooh, sauce.
-TIM: Dexter?

-Yeah.
-What do you want to say?

DEXTER:
Yeah, I mean,

Cornelius was himself,
so it shows.

He took any chance he could
to get you

-off your game
and take you down. -Right.

Dexter, did I not come up
to you guys and be like,

"You know what? Honestly, I'm
not gonna talk [bleep] about you

as a person, but I will talk
about your clothing."

They asked me my opinion,
I'm gonna give it to you.

NATHALIA:
If they ask you a question.

But you can never say that I was
ever fake about something.

-Yeah, I can. I just did.
-Yes, you... About what?

-You're fake about it.
-About what? 'Cause

everything that I said, I made
sure I said it to your face.

-Nope, you didn't. That's not
true at all. -Yes, I did. Aah.

-Oh! -DEXTER: Yeah, [bleep].
-I would... Huh?

I said how I felt to you
to your face.

-Whatever. -It's fine.
I mean... You're fine.

We're fine with that, but...
You're fine with what you said,

but you're not fine
with what I said.

Listen, at the end of the day,
apparently, like,

we were all mean girls,
so, whatever.

So what do you want to do today?

TIM:
Well, I want to say this.

Cornelius is not the only one
who was throwing shade.

When we come back, we're going

to take a look at what
you all said in the privacy

of the interview room.

-Ooh! -Whoa!
-Shady!

TIM: Coming up on the Project
Runway season 15 reunion...

I thought we were all buddies.

-That's fake.
-Smug and abrasive.

I want to hear
about that [bleep].

Who would you shag,
marry or k*ll?

No reunion has ever
gone here before.

♪ ♪

Welcome back.
Many of you

had quite a lot to say

when no one was watching.

Let's take a look.

Cornelius is this little ball
of stress, so anytime

any tiny thing happens,
he kind of freaks out.

-I think we're good.
-JENNI: The plates

kind of just look
like toenail clippings

-that were kind of just...
-[laughs]

...like, layered
and painted green.

CORNELIUS:
How many times

can you create a circle skirt?

I'm not impressed at all.

DEXTER:
I'm sitting there thinking,

who pooped on your dress?
Is there

-a really, really large
seagull... -Sorry!

...flying around somewhere that
hit the quan on your piece?

RIK: I think Mah-Jing's dress
looks like

-a potato sack.
-Oh! It did! It did!

SARAH:
I can't see anybody

walking along a beach wearing
this Victorian nightie.

I think my great-grandmother's
last words were, like,

don't you dare bury me

-in Alex's swimsuit.
-[laughter]

ALEX: Brik's look is bland,
and he could barely sew

a stretch pair
of pants together.

It is a complete middle finger

to all the hard work
that all the other designers

in the workroom have done. I
think it's time for you to go.

NATHALIA: Those ostrich
feathers. It's just really ugly

but she is feeling herself
right now.

She is like... Ah.

CORNELIUS: Erin totally doesn't
know what streetwear is.

Honestly...

Not good.
Not good at all.

NATHALIA: Looking at the jacket
that Erin is doing right now,

she does seem like a little bit
of a one-trick pony.

It is getting old.

ERIN:
I think Nathalia

has a lot of growing to do.

She's very young,

she has a lot of energy, and
that's why I think her stuff

comes out over-designed a lot.

NATHALIA: I honestly think
that Erin's piece is hideous.

It's poorly made,
the hem is uneven,

kind of looks
like a decorated bathrobe.

RIK: I have no idea
what powerful woman

would want to look like...
Patrick

from SpongeBob SquarePants.
-[laughter]

I do not think that Erin
deserved to win that challenge.

DEXTER: Why does
Cornelius have to come back?

It's like, ugh, just go home.

ALEX: Mah-Jing missed
the mark yet again

with an ill-fitted dress

that looked like a crime scene.

-[laughing]
-You all consumed quite a bit

-of champagne during that.
-Yeah.

-JENNI: Right.
-TIM: What thoughts do you have?

I realize, actually...
my entire life,

people told me to watch my tone,

and I never understood that,

'cause I always try
to be levelheaded.

And being a blunt person,

it came off much more harsh
than what the intention was.

-Well, it's good that you can be
analytical about it -Yeah.

-and-and respond positively
to it. -Yeah.

-Can I say something?
-Of course.

Thank God I'm the church girl,

and they didn't show nothin',
but...

-[laughter]
-Um, outside...

outside of that,
to be honest with you, like,

I-I hear everybody saying, "I'm
blunt, I'm blunt, I'm blunt."

Every last one of us blunt.
I am very direct and very blunt.

-But it's the way you say
things. -DEXTER: Thank you.

-It's all about how you say it.
-Thank you. Exactly.

BRIK: I think
one thing we all need to...

to remember is that talking down

about somebody else
or their work,

it doesn't make you appear
any better.

NATHALIA: I just think when
you're under pressure and you're

doing a competition,
I think you just kind of just,

-like, vomit words.
That's just... -[laughs]

I'm not taking anything back,
but I feel

like we were
all under a lot of pressure.

I think about you two,
the way you guys word things

is-is a little
on the nastier side.

It was kind of hurtful for me,
'cause I was like,

"Wait a second, like, I thought
we were all buddies." Like,

-just... for me,
it was a surprise. -I mean...

I mean,
I just want to say, like,

if I hurt anybody's feelings,
I'm truly sorry,

because I never want to be
the person to hurt someone.

-I always try to be positive
and kind, -But that's, like,

-so... -the thing that I think
is really interesting

about you, Nathalia,
is that you do say that you want

to be positive and kind
all the time, but, like...

-Then when you're alone.
-But then when you're alone,

-you're not. -I keep hearing
people saying they're real.

"I'm being real,
I'm being real." But real is

-when you say it
to people's face. -Yeah.

Yeah, but how would... How mean
would it look if someone went up

to someone and was like,
"This sucks. It's so ugly.

-You should do it over"?
-Then don't say it at all.

Don't be smug and abrasive
if you can't handle it later.

So do you feel that-that
designers in this season

were duplicitous?
Would say something to...

-Smug and abrasive. Yeah. -Okay.
-I think that there's just,

like... You don't have
to like everything.

There's no way you could ever
like everything in this world.

You guys were actually
really fake to people as well.

-I wasn't fake to anybody.
-Yes, you were, honey. You would

always give compliments
to people's outfits

when it looked a hot mess.
And instead

of saying it to their face.
Like...

But you would go around and be
like, "Oh, my God, it's so cute.

It's so cute." And yet
that person's on the bottom.

That's fake. So don't ever say

-that "I'm not fake." -Judges'
choice. That's the judges'

choice. That's not...
has anything to do with me.

You're like,
"Oh, my God, I love it so much.

-I love it so much." -It's okay
if I like someone's stuff.

Like, I don't understand why
I'm getting pounded for that.

-But do you really?
That's the... -Yeah.

Because I respect
other people's aesthetics.

Then, after a while, you thought
you were better than people.

No, I just respect other
people's aesthetic.

And that's
what I didn't like either, so...

Well, I knew this would be an-an
incendiary topic, andt was.

So let's move on. Linda,

you tried out for Project Runway
several times,

and you finally made it.
First of all,

-how did that feel?
-It was a dream

come true.
[chuckles] You know?

It was my chance,
uh, to reinvent myself.

-That's wonderful.
-And, you know what,

I went home and I was talking

to my kids and I said,
"Failure's actually

"a really good thing. You need
to look at what you did wrong,

reassess it, and push forward."

Well, we knew that women
would see you take on

this adventure
and be very inspired.

-Thank you.
-Very. So we thank you. -Linda.

-Ian, when you and I
-Yes, sir.

-had our critique together,
you were very adamant -Yes.

that
your unconventional challenge

was unconventional enough.

While I respect your aesthetic,
it seems very basic.

-Think about expanding this into
more volume. -I hate volume.

I don't like to do
[bleep] over the top.

-Do you still feel that way?
-Honestly,

when that walked down
the runway, I was really happy

with it. When I stood up there,

-I was surprised that I was
in the bottom. -We have no idea

-what the judges are going
to say. -True. -Right.

-We have... just have no idea.
-Right. Absolutely.

I guess I have learned
from Project Runway is to be...

-less inflexible.
-Yeah.

Be open to change.

Good. I'm happy to hear that.

Excellent.
Well, since we are at FIDM,

earlier this week, I went out
to talk to the students.

And they have questions for you.

-Wow. -Oh.
-All right?

So let's take a look.

I'm here at FIDM with Spencer.

And, Spencer,
who's your question for?

My question
is actually for Brik.

Brik, of all designers
this season, who would you shag,

-marry, or k*ll? -Ooh.
-[gasping, laughter]

-[cheering]
-Yes!

-Yes!
-Okay, I would definitely k*ll

Cornelius. Um... [chuckles]
I would shag Dexter,

-and I would marry Tim.
-Oh. -[gasping, laughter]

-Thank you.
-[laughter, applause]

-Lovely. -I'm-I'm storming out
of here now. Oh, my God.

I'm the one who should storm
out. He's... Brik is

-two-timing me with you.
-I know.

-Right.
-It's the poom-poom.

He's trying to get
the shnew-shnew.

I guess you must have quite
a shnew-shnew.

[laughter]

Wow. No reunion
has ever gone here before.

-[laughter]
-What else do we have?

I found another Gunn.
And his name is Ryan.

So, Ryan, ask away.

RYAN: Jenni, you said
during the universal challenge

that Laurence
is a one-trick pony.

JENNI: I feel like Laurence
is just using one technique

and spreading it out
amongst different looks.

So it's, like,
borderline one-trick pony.

-[gasps] -Laurence,
what do you think about that?

-Yeah, I want to hear
about that [bleep]. -[laughter]

-JENNI: No, honestly, like...
-LAURENCE: Let's talk.

The only thing I could think of
was, like, the repeat shoulders.

But you see, if you paid
attention, there was no repeat

-shoulders. -I know. You changed
it. Yeah, you did change it.

And I thought so, too.
I was like, "Laurence, like,

-understands
where I'm coming from." -Right.

No, I don't understand,
but I didn't care.

-JENNI: No. Yeah, exactly.
-[laughter]

-Yeah. At the end of the day.
-You know, it's like...

-It doesn't affect me.
-TIM: All right, we're going

to take a break.
And when we come back,

there's a clip that
I'm a little bit nervous about.

-[gasping]
-[Nathalia laughing]

♪ ♪

♪ ♪

Welcome back, everyone.

The producers put together
a clip

-that they're calling Tim-isms.
-Oh.

-Tim-isms. -And
I'm a little nervous about it.

So let's take a look.

It's just blah.

I find it unfathomable.

It's just perplexing.

Uh...

Eesh.

Blah.

[Nathalia laughing]

Now I'm very scared.

You're giving me that "I've
just had a bad piece of seafood"

-look again. Figure it out.
-Oh, God.

-I will.
-Really?

Does this say cool?

DEXTER:
Your eyes are telling me no?

-Make it work.
-Caucus.

-Own the Bride of Tin Man.
-Okay.

-Like this?
-Do it. Do you.

Don't push street
into the c*ck.

Push c*ck into the street.

No worries. Let me make
something really quick.

Grace Jones
is totally ignoring me.

The judges love yellow.

-You have a "make it work"
moment. -I think it's smashing.

It's not often that I stand
in here and I have chills.

-[gasps]
-It's now become

-a fine arts painting project.
-I'll make it work.

-You have to.
-I have to.

Danke, Mood.

Gracias, Mood.

ALL:
Gracias, Mood.

ALL:
Merci, Mood!

-I'll make it work. We
always did, right, Tim? -Well,

that wasn't as bad
as I was expecting.

And I have to tell all of you,

I loved this season,
and it's because of you.

You each brought something
that was so unique and special

to the show,
and it was one of my favorites.

-Aw. -Yay!
-So I thank you. And, Erin,

-congratulations to you again.
-Thank you. -[cheering]

And to all of our loyal fans,

thank you for watching season
after season. We love you.

And don't go anywhere,
because Project Runway Junior

starts right now. Yay!

[cheering and applause]

♪ ♪

It's called
the Designer's Prayer by Tasha.

Dear God, thank you
for the knowledge of fashion

you blessed us with.
Please bless our families,

each director, producer,

executive producer,
attorney, grip,

A.D., talent management, editor,

audio, interviewer, driver,

intern, assistant, judge, model,

hair stylist, M.U.A., cameraman,

medic, talent,
and anyone that has a hand

in Project Runway
and Lifetime Productions.

Amen.

♪ ♪

HEIDI: Visit myLifetime.com
to learn more

about the fashion
you've seen on tonight's show.